La solution aux révisions : Opération Bib'Bosse !

Val Parisis Agglo

La solution aux révisions : Opération Bib'Bosse !

Opération Bib' Bosse, cette année, ça sera du 12 au 23 juin 2018 !
C'est gratuit, c'est organisé par les 16 bibliothèques du territoire de l'agglo et c'est surtout pendant plus de 10 jours :
- plus d’espaces pour réviser seul ou en groupe ;
- des ressources documentaires dont plus de 400 nouveautés mises à disposition (annales, méthodes de travail, programmes de révision par matières), une sitothèque (bibliothèque de sites web), une applithèque (sélection d’applications numériques), une moocthèque (ressources numériques d’autoformation) ;
- des animations courtes, gratuites et en libre accès : siestes électroniques, relaxation musicale, coaching, jeux, instants transats-parasols…
- des équipes mobilisées et disponibles ;
- des pauses gourmandes et des distributions de goodies.
Le portail des médiathèques : http://mediatheques.valparisis.fr/
Le Facebook des médiathèques : https://www.facebook.com/valparisismediatheques/
Le site de Val Parisis : http://www.valparisis.fr/

24/04/2018